==> modonomicon-1.20.1-fabric-1.79.0-sources.jar: com/klikli_dev/modonomicon/api/datagen/book/BookEntryParentModel.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.api.datagen.book;

import com.google.gson.JsonObject;
import net.minecraft.class_2960;

public class BookEntryParentModel {
    protected class_2960 entryId;
    protected boolean drawArrow = true;
    protected boolean lineEnabled = true;
    protected boolean lineReversed = false;

    protected BookEntryParentModel(class_2960 entryId) {
        this.entryId = entryId;
    }

    public static BookEntryParentModel create(class_2960 entryId) {
        return new BookEntryParentModel(entryId);
    }

    public JsonObject toJson() {
        JsonObject json = new JsonObject();
        json.addProperty("entry", this.entryId.toString());
        json.addProperty("draw_arrow", this.drawArrow);
        json.addProperty("line_enabled", this.lineEnabled);
        json.addProperty("line_reversed", this.lineReversed);
        return json;
    }

    public class_2960 getEntryId() {
        return this.entryId;
    }

    public boolean isDrawArrow() {
        return this.drawArrow;
    }

    public boolean isLineEnabled() {
        return this.lineEnabled;
    }

    public boolean isLineReversed() {
        return this.lineReversed;
    }

    public BookEntryParentModel withEntryId(class_2960 entryId) {
        this.entryId = entryId;
        return this;
    }

    public BookEntryParentModel withDrawArrow(boolean drawArrow) {
        this.drawArrow = drawArrow;
        return this;
    }

    public BookEntryParentModel withLineEnabled(boolean lineEnabled) {
        this.lineEnabled = lineEnabled;
        return this;
    }

    public BookEntryParentModel withLineReversed(boolean lineReversed) {
        this.lineReversed = lineReversed;
        return this;
    }
}

==> modonomicon-1.21.1-fabric-1.117.2-sources.jar: com/klikli_dev/modonomicon/api/datagen/book/BookEntryParentModel.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.api.datagen.book;

import com.google.gson.JsonObject;
import net.minecraft.class_2960;
import net.minecraft.class_7225;

public class BookEntryParentModel {
    protected class_2960 entryId;
    protected boolean drawArrow = true;
    protected boolean lineEnabled = true;
    protected boolean lineReversed = false;

    protected BookEntryParentModel(class_2960 entryId) {
        this.entryId = entryId;
    }

    public static BookEntryParentModel create(class_2960 entryId) {
        return new BookEntryParentModel(entryId);
    }

    /**
     * @param ownerEntryId the entry id of the entry that contains this parent information. This is the CHILD not the parent.
     * @param provider a registry / holder lookup provider.
     */
    public JsonObject toJson(class_2960 ownerEntryId, class_7225.class_7874 provider) {
        JsonObject json = new JsonObject();

        //if we are in the same namespace, which we basically always should be, omit namespace
        if (this.entryId.method_12836().equals(ownerEntryId.method_12836()))
            json.addProperty("entry", this.entryId.method_12832());
        else
            json.addProperty("entry", this.entryId.toString());

        json.addProperty("draw_arrow", this.drawArrow);
        json.addProperty("line_enabled", this.lineEnabled);
        json.addProperty("line_reversed", this.lineReversed);
        return json;
    }

    public class_2960 getEntryId() {
        return this.entryId;
    }

    public boolean isDrawArrow() {
        return this.drawArrow;
    }

    public boolean isLineEnabled() {
        return this.lineEnabled;
    }

    public boolean isLineReversed() {
        return this.lineReversed;
    }

    public BookEntryParentModel withEntryId(class_2960 entryId) {
        this.entryId = entryId;
        return this;
    }

    public BookEntryParentModel withDrawArrow(boolean drawArrow) {
        this.drawArrow = drawArrow;
        return this;
    }

    public BookEntryParentModel withLineEnabled(boolean lineEnabled) {
        this.lineEnabled = lineEnabled;
        return this;
    }

    public BookEntryParentModel withLineReversed(boolean lineReversed) {
        this.lineReversed = lineReversed;
        return this;
    }
}
